@@ -4,8 +4,8 @@
 #' required by all other functions.
 #' @param username (string) RobinHood username
 #' @param password (string) RobinHood password
-#' @import curl jsonlite magrittr
-#' @export
+#' @import httr jsonlite magrittr
+
 api_login <- function(username, password) {
 
   # Storage for api data
@@ -15,26 +15,28 @@ api_login <- function(username, password) {
     api_client_id = "c82SH0WZOsabOXGP2sxqcj34FxkvfnWRZBKlBjFS"
   )
 
-  # Get current positions
+  # Parameters
   detail <- paste("?grant_type=", RH$api_grant_type,
                   "&client_id=", RH$api_client_id,
                   "&username=", username,
                   "&password=", password, sep = "")
 
-  auth <- httr::POST(paste(api_endpoints("token"), detail, sep = ""))
-  auth <- httr::content(auth, type = "json")
-  auth <- jsonlite::fromJSON(rawToChar(auth))
+  url <- paste(api_endpoints("token"), detail, sep = "")
 
-  access_token <- auth$access_token
-  refresh_token <- auth$refresh_token
+  # POST call
+  dta <- POST(url) %>%
+    content(type = "json") %>%
+    rawToChar() %>%
+    jsonlite::fromJSON() %>%
+    as.list()
 
   # Return object
   RH <- c(RH,
-    # User tokens and ids
-    tokens = list(
-      access_token = access_token,
-      refresh_token = refresh_token)
-    )
+          # User tokens and ids
+          tokens = list(
+            access_token = dta$access_token,
+            refresh_token = dta$refresh_token)
+  )
 
   return(RH)
 }
