@@ -6,6 +6,7 @@
 #' @param symbol (string) Stock symbol to query, single symbol only
 #' @param interval (string) Interval of time to aggregate to (examples: hour, day, week, month)
 #' @param span (string) Period of time you are interested in (examples: day, week, month, year)
+#' @param tz (string) timezone returned by OlsonNames() (eg: "America/Chicago")
 #' @import httr magrittr
 #' @export
 #' @examples
@@ -16,7 +17,7 @@
 #' get_historicals (RH = RH, symbol = "CAT", interval = "day", span = "month")
 #'
 #'}
-get_historicals <- function(RH, symbol, interval, span) {
+get_historicals <- function(RH, symbol, interval, span, tz = Sys.timezone()) {
 
     # Check if RH is valid
     check_rh(RH)
@@ -33,5 +34,18 @@ get_historicals <- function(RH, symbol, interval, span) {
     # Call the historical api for price history
     historicals <- api_historicals(RH, historicals_url, body)
 
+    # If interval is hour or minute, then adjust timezone to local or user override
+    if (length(grep("hour|minute", x = interval)) == 1) {
+
+      historicals <- historicals %>%
+        dplyr::mutate_at("begins_at", function(x) lubridate::with_tz(lubridate::ymd_hms(x), tzone = tz))
+
+    } else {
+
+      historicals <- historicals %>%
+        dplyr::mutate_at("begins_at", lubridate::ymd)
+
+    }
+
     return(historicals)
   }
